TaprootTransactionSignatureMetadata class
Provides data of Taproot transaction inputs to be signed.
The consumer should only approve signatures requests for transactions that they approve and they should check that the inputs are solveable for the derived signing key.
The SignaturesRequestDetails class uses verifyRequiredSigs to verify that the SingleSignatureDetails messages correspond to the inputs being signed. The consumer should check that the key and MAST hash are correct.
- Inheritance
-
- Object
- SignatureMetadata
- TaprootTransactionSignatureMetadata
Constructors
-
TaprootTransactionSignatureMetadata({required Transaction transaction, required List<
TaprootSignDetails> signDetails}) -
Takes the
transactionto be signed and thesignDetailsfor all inputs to sign which must carry the sametransactionobject.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signDetails
→ List<
TaprootSignDetails> -
The details for each input to be signed
final
- size → int
-
Obtains the cached size of the object
no setterinherited
- transaction → Transaction
-
The transaction being signed
final
- type → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List -
Obtains a cached Uint8List with data serialized for this object
inherited
-
toHex(
) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyRequiredSigs(
List< SingleSignatureDetails> requiredSigs) → bool -
Each element in
requiredSigsmust have a message that corresponds to each element in signDetails.override -
write(
Writer writer) → void -
Override to write data into
writer
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited