dispose method
May be called when the underlying rust object is no longer needed to clear memory before GC.
Implementation
@override
void dispose() {
_bytesCache = null;
super.dispose();
}
May be called when the underlying rust object is no longer needed to clear memory before GC.
@override
void dispose() {
_bytesCache = null;
super.dispose();
}